GUI
===

There is a limited GUI available that can be used to perform channel alignment, molecule localization, trace extraction and basic trace visualization. Before molecule localization the default spatial background correction is performed.

To start the GUI double click the ``Start GUI.cmd`` file (Windows) or ``Start GUI.command`` file (Mac).
Alternatively, directly run ``Start GUI.py``.